summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/document_source.h
diff options
context:
space:
mode:
authorCharlie Swanson <charlie.swanson@mongodb.com>2017-11-15 09:40:53 -0500
committerCharlie Swanson <charlie.swanson@mongodb.com>2017-11-15 10:53:49 -0500
commite37db69674486dff9fdac2b5ee41961a8805804b (patch)
tree14b519e3e0f80bff99e4762d7d5dd33efeb5d1fd /src/mongo/db/pipeline/document_source.h
parente60188fe153cccc2f6ffa44b422f2be66a84d90c (diff)
downloadmongo-e37db69674486dff9fdac2b5ee41961a8805804b.tar.gz
SERVER-31447 Use correct collation for update lookup
Diffstat (limited to 'src/mongo/db/pipeline/document_source.h')
-rw-r--r--src/mongo/db/pipeline/document_source.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/mongo/db/pipeline/document_source.h b/src/mongo/db/pipeline/document_source.h
index 2f6bec9fbcc..0ecd0fcf92a 100644
--- a/src/mongo/db/pipeline/document_source.h
+++ b/src/mongo/db/pipeline/document_source.h
@@ -841,13 +841,15 @@ public:
virtual std::vector<FieldPath> collectDocumentKeyFields(UUID) const = 0;
/**
* Returns zero or one documents matching the input filter, or throws if more than one match
* was found. The passed ExpressionContext may use a different namespace than the
* ExpressionContext used to construct the MongoProcessInterface. Returns boost::none if no
* matching documents were found, including cases where the given namespace does not exist.
*/
- virtual boost::optional<Document> lookupSingleDocument(
- const boost::intrusive_ptr<ExpressionContext>& expCtx, const Document& filter) = 0;
+ virtual boost::optional<Document> lookupSingleDocument(const NamespaceString& nss,
+ UUID collectionUUID,
+ const Document& documentKey) = 0;
/**
* Returns a vector of all local cursors.
@@ -841,13 +841,15 @@ public:
virtual std::vector<FieldPath> collectDocumentKeyFields(UUID) const = 0;
/**
- * Returns zero or one documents matching the input filter, or throws if more than one match
- * was found. The passed ExpressionContext may use a different namespace than the
- * ExpressionContext used to construct the MongoProcessInterface. Returns boost::none if no
- * matching documents were found, including cases where the given namespace does not exist.
+ * Returns zero or one documents with the document key 'documentKey'. 'documentKey' is
+ * treated as a unique identifier of a document, and may include an _id or all fields from
+ * the shard key and an _id. Throws if more than one match was found. Returns boost::none if
+ * no matching documents were found, including cases where the given namespace does not
+ * exist.
*/